@@ -198,23 +198,29 @@ def extract_qualys(
 
                 etld_lib_functions.logger.info(f"Qualys Headers: {qualys_headers}")
                 if r.status_code == 200:
-                    with open(output_file, "w", encoding='utf-8') as f:
+                    with open(output_file, "wb") as f:
                         for chunk in r.iter_content(chunk_size=chunk_size_calc):
                             try:
-                                f.write(chunk.decode('utf-8'))
+                                 f.write(chunk)
                             except Exception as e:
                                 f.write(etld_lib_functions.remove_low_high_values(chunk).decode('utf-8'))
                     extract_validation(validation_type=extract_validation_type, output_file_to_validate=output_file)
+                elif r.status_code == 409 or r.status_code == 202:  # Concurrency Issue or Duplicate Operation.
+                    message = get_http_error_code_message_v2_api(str(r.status_code))
+                    etld_lib_functions.logger.warning(f"HTTP USER: {cred_dict['username']} url: {url}")
+                    raise Exception(f"HTTP Status is: {r.status_code}, message: {message}")
                 else:
                     message = get_http_error_code_message_v2_api(str(r.status_code))
                     etld_lib_functions.logger.error(f"HTTP USER: {cred_dict['username']} url: {url}")
                     etld_lib_functions.logger.error(f"HTTP {r.status_code}, exiting. message={message}")
                     exit(1)
         except Exception as e:
+            time_sleep = 120
             etld_lib_functions.logger.warning(f"Warning for extract file: {Path(output_file).name}")
             etld_lib_functions.logger.warning(f"Warning {e}")
+            etld_lib_functions.logger.warning(f"Sleeping for {time_sleep} seconds before next retry.")
             etld_lib_functions.logger.warning(f"Retry attempt number: {_ + 1}")
-            time.sleep(60)
+            time.sleep(time_sleep)
             continue
         else:
             break  # success
